========
Examples
========


Black (pyproject.toml)
======================


.. literalinclude:: examples/black-pyproject.toml/pyproject.toml
.. literalinclude:: examples/black-pyproject.toml/black.py
.. literalinclude:: examples/black-pyproject.toml/test.console
   :language: console



.. _example-pytest:

Pytest
======



.. _example-python-gitlab:

Python-Gitlab
=============

.. literalinclude:: examples/python-gitlab/python-gitlab.toml
.. literalinclude:: examples/python-gitlab/python_gitlab.py
.. literalinclude:: examples/python-gitlab/test.console
   :language: console


.. _example-twine:

.pypirc
=======

Original
--------

.. literalinclude:: examples/pypirc_0/pypirc.toml
.. literalinclude:: examples/pypirc_0/pypirc_0.py
.. literalinclude:: examples/pypirc_0/test.console
   :language: console

Improved
--------

.. literalinclude:: examples/pypirc_1/pypirc.toml
.. literalinclude:: examples/pypirc_1/pypirc_1.py
.. literalinclude:: examples/pypirc_1/test.console
   :language: console
